@@ -67,7 +67,7 @@ class CRM_Case_Form_Activity_ChangeCaseStartDate {
     $openCaseParams = array('activity_type_id' => $openCaseActivityType);
     $openCaseInfo = CRM_Case_BAO_Case::getCaseActivityDates($caseId, $openCaseParams, TRUE);
     if (empty($openCaseInfo)) {
-      list($defaults['start_date'], $defaults['start_date_time']) = CRM_Utils_Date::setDateDefaults();
+      $defaults['start_date'] = date('Y-m-d H:i:s');
     }
     else {
       // We know there can only be one result
@@ -76,7 +76,7 @@ class CRM_Case_Form_Activity_ChangeCaseStartDate {
       // store activity id for updating it later
       $form->openCaseActivityId = $openCaseInfo['id'];
 
-      list($defaults['start_date'], $defaults['start_date_time']) = CRM_Utils_Date::setDateDefaults($openCaseInfo['activity_date'], 'activityDateTime');
+      $defaults['start_date'] = $openCaseInfo['activity_date'];
     }
     return $defaults;
   }
@@ -91,7 +91,7 @@ class CRM_Case_Form_Activity_ChangeCaseStartDate {
 
     $currentStartDate = CRM_Core_DAO::getFieldValue('CRM_Case_DAO_Case', $caseId, 'start_date');
     $form->assign('current_start_date', $currentStartDate);
-    $form->addDate('start_date', ts('New Start Date'), FALSE, array('formatType' => 'activityDateTime'));
+    $form->add('datepicker', 'start_date', ts('New Start Date'), [], TRUE);
   }
 
   /**
@@ -132,10 +132,6 @@ class CRM_Case_Form_Activity_ChangeCaseStartDate {
    * @param $activity
    */
   public static function endPostProcess(&$form, &$params, $activity) {
-    if (!empty($params['start_date'])) {
-      $params['start_date'] = CRM_Utils_Date::processDate($params['start_date'], $params['start_date_time']);
-    }
-
     $caseType = CRM_Utils_Array::first($form->_caseType);
     $caseId = CRM_Utils_Array::first($form->_caseId);
 
@@ -162,7 +158,7 @@ class CRM_Case_Form_Activity_ChangeCaseStartDate {
     $currentStartDate = CRM_Utils_Date::customFormat(CRM_Core_DAO::getFieldValue('CRM_Case_DAO_Case',
       $caseId, 'start_date'
     ), $config->dateformatFull);
-    $newStartDate = CRM_Utils_Date::customFormat(CRM_Utils_Date::mysqlToIso($params['start_date']), $config->dateformatFull);
+    $newStartDate = CRM_Utils_Date::customFormat($params['start_date'], $config->dateformatFull);
     $subject = 'Change Case Start Date from ' . $currentStartDate . ' to ' . $newStartDate;
     $activity->subject = $subject;
     $activity->save();
