@@ -125,6 +125,14 @@ class CRM_Report_Form_Contribute_PCP extends CRM_Report_Form {
             'type' => CRM_Utils_Type::T_STRING,
           ),
         ),
+        'group_bys' => array(
+          'pcp_id' => array(
+            'name' => 'id',
+            'required' => TRUE,
+            'default' => TRUE,
+            'title' => ts('Personal Campaign Page'),
+          ),
+        ),
         'grouping' => 'pcp-fields',
       ),
       'civicrm_contribution_soft' => array(
@@ -204,6 +212,7 @@ class CRM_Report_Form_Contribute_PCP extends CRM_Report_Form {
     );
 
     parent::__construct();
+    $this->optimisedForOnlyFullGroupBy = FALSE;
   }
 
   public function from() {
@@ -236,10 +245,6 @@ LEFT JOIN civicrm_event {$this->_aliases['civicrm_event']}
     $this->addFinancialTrxnFromClause();
   }
 
-  public function groupBy() {
-    $this->_groupBy = CRM_Contact_BAO_Query::getGroupByFromSelectColumns($this->_selectClauses, "{$this->_aliases['civicrm_pcp']}.id");
-  }
-
   public function orderBy() {
     $this->_orderBy = " ORDER BY {$this->_aliases['civicrm_contact']}.sort_name ";
   }
