@@ -574,7 +574,7 @@ LEFT JOIN $this->tempTableRepeat2 {$this->_aliases['civicrm_contribution']}2
     }
     else {
       foreach ($fields['fields'] as $fld_id => $value) {
-        if (!($fld_id == 'total_amount1') && !($fld_id == 'total_amount2')) {
+        if (!($fld_id == 'total_amount1') && !($fld_id == 'total_amount2') && !(substr($fld_id, 0, 7) === "custom_")) {
           $found = FALSE;
           $invlidGroups = array();
           foreach ($fields['group_bys'] as $grp_id => $val) {
@@ -833,6 +833,7 @@ GROUP BY    currency
     $this->buildGroupTempTable();
     $this->select();
     $this->from();
+    $this->customDataFrom();
     $this->where();
     $this->groupBy();
     $this->orderBy();
