@@ -3,12 +3,11 @@
 namespace Civi\Api4\Action\Address;
 
 use Civi\Api4\Generic\Result;
-use Civi\Api4\Action\Update as DefaultUpdate;
 
 /**
  * @inheritDoc
  */
-class Update extends DefaultUpdate {
+class Update extends \Civi\Api4\Generic\DAOUpdateAction {
 
   /**
    * Optional param to indicate you want the street_address field parsed into individual params
