@@ -1,13 +1,12 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * CustomField entity.
  *
  * @package Civi\Api4
  */
-class CustomField extends AbstractEntity {
+class CustomField extends Generic\DAOEntity {
 
 }
