@@ -1,13 +1,12 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * CustomGroup entity.
  *
  * @package Civi\Api4
  */
-class CustomGroup extends AbstractEntity {
+class CustomGroup extends Generic\DAOEntity {
 
 }
