@@ -1,7 +1,6 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * Email entity.
@@ -12,6 +11,6 @@ use Civi\Api4\Generic\AbstractEntity;
  *
  * @package Civi\Api4
  */
-class Email extends AbstractEntity {
+class Email extends Generic\DAOEntity {
 
 }
