@@ -1,13 +1,12 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * Group entity.
  *
  * @package Civi\Api4
  */
-class Group extends AbstractEntity {
+class Group extends Generic\DAOEntity {
 
 }
