@@ -1,13 +1,12 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * OpenID entity.
  *
  * @package Civi\Api4
  */
-class OpenID extends AbstractEntity {
+class OpenID extends Generic\DAOEntity {
 
 }
