@@ -1,13 +1,12 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * OptionValue entity.
  *
  * @package Civi\Api4
  */
-class OptionValue extends AbstractEntity {
+class OptionValue extends Generic\DAOEntity {
 
 }
