@@ -1,7 +1,6 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * Phone entity.
@@ -12,6 +11,6 @@ use Civi\Api4\Generic\AbstractEntity;
  *
  * @package Civi\Api4
  */
-class Phone extends AbstractEntity {
+class Phone extends Generic\DAOEntity {
 
 }
