@@ -1,13 +1,12 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * Relationship entity.
  *
  * @package Civi\Api4
  */
-class Relationship extends AbstractEntity {
+class Relationship extends Generic\DAOEntity {
 
 }
