@@ -1,13 +1,12 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * UFGroup entity - AKA profiles.
  *
  * @package Civi\Api4
  */
-class UFGroup extends AbstractEntity {
+class UFGroup extends Generic\DAOEntity {
 
 }
