@@ -1,13 +1,12 @@
 <?php
 
 namespace Civi\Api4;
-use Civi\Api4\Generic\AbstractEntity;
 
 /**
  * Website entity.
  *
  * @package Civi\Api4
  */
-class Website extends AbstractEntity {
+class Website extends Generic\DAOEntity {
 
 }
