@@ -7,19 +7,20 @@ use Civi\Test\Api4\Traits\TableDropperTrait;
 
 abstract class BaseCustomValueTest extends UnitTestCase {
 
+  use \Civi\Test\Api4\Traits\OptionCleanupTrait {
+    setUp as setUpOptionCleanup;
+  }
   use TableDropperTrait;
 
   /**
    * Set up baseline for testing
    */
   public function setUp() {
+    $this->setUpOptionCleanup();
     $cleanup_params = [
       'tablesToTruncate' => [
         'civicrm_custom_group',
         'civicrm_custom_field',
-        'civicrm_contact',
-        'civicrm_option_group',
-        'civicrm_option_value'
       ],
     ];
 
