@@ -12,15 +12,12 @@ class OptionValueJoinTest extends UnitTestCase {
 
   public function setUpHeadless() {
     $relatedTables = [
-      'civicrm_contact',
       'civicrm_address',
       'civicrm_email',
       'civicrm_phone',
       'civicrm_openid',
       'civicrm_im',
       'civicrm_website',
-      'civicrm_option_group',
-      'civicrm_option_value',
       'civicrm_activity',
       'civicrm_activity_contact',
     ];
@@ -35,6 +32,7 @@ class OptionValueJoinTest extends UnitTestCase {
     $query = new Api4SelectQuery('Contact', FALSE);
     $query->select[] = 'first_name';
     $query->select[] = 'preferred_communication_method.label';
+    $query->where[] = ['preferred_communication_method', 'IS NOT NULL'];
     $results = $query->run();
     $first = array_shift($results);
     $firstPreferredMethod = array_shift($first['preferred_communication_method']);
