@@ -1,5 +1,5 @@
 // http://civicrm.org/licensing
-CRM.$(function($) {
+(function($) {
   $(document)
     .on('dialogopen', function(e) {
       // D7 hack to get the toolbar out of the way (CRM-15341)
@@ -10,6 +10,10 @@ CRM.$(function($) {
         // D7 hack, restore toolbar position (CRM-15341)
         $('#toolbar').css('z-index', '');
       }
+    })
+    .on('crmLoad', '#civicrm-menu', function(e) {
+      if ($('#toolbar a.toggle').length) {
+        $('#civicrm-menu').css({width: 'calc(100% - 40px)'});
+      }
     });
-    $('#civicrm-menu').css({'width': '97%'});
-});
+})(CRM.$);
