@@ -364,8 +364,7 @@ class HTML_QuickForm_hierselect extends HTML_QuickForm_group
             if ($js != '') {
                 $js .= ",\n";
             }
-            $options = utf8_encode($options);
-            $js .= '"'.$optValue.'":'.json_encode($options);
+            $js .= '"'.$optValue.'":'.json_encode($options, JSON_UNESCAPED_UNICODE);
         }
     }
 
